********************************************************************************
* This file runs the analysis for Abeler and Jger: Complex Tax Incentives
********************************************************************************

********************************************************************************
* Initialize 
********************************************************************************
capture log close
set more off, permanently

global in_path = "enter your path here"
cd "${in_path}"
global out_path = "../Paper/"
global bs_reps = 1000

log using "${out_path}complex_tax_incentives_web_appendix.log", replace

use "${in_path}complex_tax_incentives_web_appendix.dta", clear

global control_vars "age female iq" 






********************************************************************************
********************************************************************************
* Result 1 
********************************************************************************
********************************************************************************



********************************************************************************
{/***** Figure 6: Histogram of Choices for Schedule A */
********************************************************************************

histogram sliders_a, discrete by(ct , cols(1) ixaxes note("") graphregion(color(white))) xline(58, lpattern(dash)) bcolor(navy) xlabel(0 50 96) xtitle("Sliders for Schedule A") ylabel(10 20 30 40,nogrid) percent
graph export "${out_path}histogram_a.pdf", replace 
}

********************************************************************************
{/***** Figure 7: Histogram of Earnings by Treatment */
********************************************************************************

gen Profit_c = Profit if ct==1
label variable Profit_c "Earnings in Complex Treatment (in {c L-})"
gen Profit_s = Profit if ct==0
label variable Profit_s "Earnings in Simple Treatment (in {c L-})"


hist Profit_c if ct==1, discrete bcolor(navy) graphregion(color(white)) ylabel(0(0.1)0.45) frac
graph save Profit_hist_complex, replace
hist Profit_s if ct==0, discrete bcolor(navy) graphregion(color(white)) ylabel(0(0.1)0.45) frac
graph save Profit_hist_simple, replace
drop Profit_c Profit_s
graph combine "Profit_hist_simple" "Profit_hist_complex", rows(2) graphregion(color(white))
graph export "${out_path}Profit_hist.pdf", replace 
rm Profit_hist_complex.gph
rm Profit_hist_simple.gph


tab profit_123 if st==1
mean profit_123, over(ct)

}


********************************************************************************
{/***** Table 6: Summary Statistics of Performance by Treatment */
********************************************************************************

tabstat fraction_max if iq<0, by(ct) statistics(mean median) 
tabstat fraction_max if iq>0, by(ct) statistics(mean median) 
tabstat fraction_max, by(ct) statistics(mean median) 


preserve
expand 2, generate(stage)
expand 2 if stage==1, generate(stage2)
replace stage=2 if stage2==1

gen sliders_prime = cond(stage==0, sliders_1, cond(stage==1, sliders_2, sliders_3))
gen diff_prime = cond(stage==0, diff_2_1, diff_3_2_prime)
gen found_opt_prime = cond(stage==0, sliders_1_found_opt, cond(stage==1, sliders_2_found_opt, sliders_3_found_opt))

forvalues lcl_stage=0/2 {
	foreach variable in found_opt_prime {
		display("Stage: `lcl_stage'")
		tabstat `variable' if stage==`lcl_stage'&iq<0, by(ct) statistics(mean median) columns(statistics)
		tabstat `variable' if stage==`lcl_stage'&iq>0, by(ct) statistics(mean median) columns(statistics)
		tabstat `variable' if stage==`lcl_stage', by(ct) statistics(mean median) columns(statistics)
	}	
}


restore
}


********************************************************************************
{/***** Table 7: Baseline Effect of Complexity */
********************************************************************************

preserve
expand 2, generate(stage)
expand 2 if stage==1, generate(stage2)
replace stage=2 if stage2==1

gen found_opt_prime = cond(stage==0, sliders_1_found_opt, cond(stage==1, sliders_2_found_opt, sliders_3_found_opt))
gen sd_prime = cond(stage==0, sd_1, cond(stage==1, sd_2, sd_3))
gen profit_prime = cond(stage==0, profit_1, cond(stage==1, profit_2, profit_3))
gen max_profit_prime = cond(stage==0, max_profit_1, cond(stage==1, max_profit_2, max_profit_3))
gen profit_prime2 = max_profit_prime - profit_prime

eststo clear

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg found_opt_prime i.ct
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg found_opt_prime i.ct i.order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg found_opt_prime i.ct i.order_abc $control_vars

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): tobit sd_prime i.ct , ll(0) 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): tobit sd_prime i.ct i.order_abc , ll(0) 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): tobit sd_prime i.ct i.order_abc $control_vars, ll(0) 

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_prime i.ct
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_prime i.ct i.order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_prime i.ct i.order_abc $control_vars

esttab using "${out_path}table_baseline_effect.tex", replace keep( 1.ct 1.order_abc age female iq _cons) drop(sigma:) order(1.ct 1.order_abc age female iq _cons ) style(tex) substitute(_ \_) ///
cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
stats(N , fmt(0 3 2) labels("N.Obs.")) ///
varlabels(1.ct "1 if CT" female "1 if Female" age "Age" 1.order_abc "1 if Choice Order A-B-C" iq "IQ Measure" _cons "Constant") ///
extracols( 4 7 ) varwidth(35) mlabels(none ) collabels(none) eqlabels(none) ///
prehead("\begin{onehalfspace} \begin{small} \begin{center} \resizebox{23cm}{!} { \begin{tabular}{l*{11}{c}} \hline \\ \multicolumn{11}{l}{Dependent variable: } \\ & \multicolumn{3}{c}{1 If optimal choice} && \multicolumn{3}{c}{Distance to optimal choice} && \multicolumn{3}{c}{Earnings} \\ \\ ") ///
postfoot(" \hline \end{tabular} } \end{center} \begin{flushleft} Notes: OLS and tobit estimates. The dependent variable is, in Columns 1--3, a dummy for choosing the payoff-maximizing output level (OLS); in columns 4- 6, the distance to the payoff-maximizing choice (tobit with lower limit at 0); and in Columns 7--9, the earnings from the decision measured in points per round (OLS; 7 points were exchanged into one British pence). Each subject enters the regression three times, standard errors computed by block bootstrap clustered at the subject level are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{small} \end{onehalfspace}")

restore



 
ttest total_sliders, by(ct) 


}



********************************************************************************
{/******* Analysis of Behavior in CT ****/
********************************************************************************

* Average profit if subjects drew their sliders from a uniform random distribution: schedule A = 2475; schedule B = 923; schedule C = -724
ttest profit_a = 2475 if ct
ttest profit_b = 923 if ct
ttest profit_c = -724 if ct


* I) how does optimal choice in round t compare to actual choice in t-1

* CT
local correct = 0
count if ct & order_abc & diff_2_1<0 & sliders_1>42 
local correct = `correct' + r(N)
count if ct & order_abc & diff_2_1==0 & sliders_1==42 
local correct = `correct' + r(N)
count if ct & order_abc & diff_2_1>0 & sliders_1<42 
local correct = `correct' + r(N)
count if ct & order_acb & diff_2_1<0 & sliders_1>25 
local correct = `correct' + r(N)
count if ct & order_acb & diff_2_1==0 & sliders_1==25 
local correct = `correct' + r(N)
count if ct & order_acb & diff_2_1>0 & sliders_1<25 
local correct = `correct' + r(N)

count if ct & order_abc & diff_3_2<0 & sliders_2>25 
local correct = `correct' + r(N)
count if ct & order_abc & diff_3_2==0 & sliders_2==25 
local correct = `correct' + r(N)
count if ct & order_abc & diff_3_2>0 & sliders_2<25 
local correct = `correct' + r(N)
count if ct & order_acb & diff_3_2<0 & sliders_2>42 
local correct = `correct' + r(N)
count if ct & order_acb & diff_3_2==0 & sliders_2==42 
local correct = `correct' + r(N)
count if ct & order_acb & diff_3_2>0 & sliders_2<42 
local correct = `correct' + r(N)
di `correct'/(2*197)



* ST
local correct = 0
count if st & order_abc & diff_2_1<0 & sliders_1>42 
local correct = `correct' + r(N)
count if st & order_abc & diff_2_1==0 & sliders_1==42 
local correct = `correct' + r(N)
count if st & order_abc & diff_2_1>0 & sliders_1<42 
local correct = `correct' + r(N)
count if st & order_acb & diff_2_1<0 & sliders_1>25 
local correct = `correct' + r(N)
count if st & order_acb & diff_2_1==0 & sliders_1==25 
local correct = `correct' + r(N)
count if st & order_acb & diff_2_1>0 & sliders_1<25 
local correct = `correct' + r(N)

count if st & order_abc & diff_3_2<0 & sliders_2>25 
local correct = `correct' + r(N)
count if st & order_abc & diff_3_2==0 & sliders_2==25 
local correct = `correct' + r(N)
count if st & order_abc & diff_3_2>0 & sliders_2<25 
local correct = `correct' + r(N)
count if st & order_acb & diff_3_2<0 & sliders_2>42 
local correct = `correct' + r(N)
count if st & order_acb & diff_3_2==0 & sliders_2==42 
local correct = `correct' + r(N)
count if st & order_acb & diff_3_2>0 & sliders_2<42 
local correct = `correct' + r(N)
di `correct'/160


* II) assume subjects are at optimum in round t-1 or they think they are at optimum in round t-1

foreach t in ct st {

	qui count if `t' 
	local n_`t' = r(N)
	qui count if `t' & diff_2_1<0 // strictly correct direction
	local `t'_12_strictly = r(N)/`n_`t''

	qui count if `t' & ((diff_3_2<0 & order_abc) | (diff_3_2>0 & order_acb)) // strictly correct direction
	local `t'_23_strictly = r(N)/`n_`t''

	di "Strictly correct direction (`t') across both changes: " (``t'_12_strictly' + ``t'_23_strictly')/2
	
}


}




********************************************************************************
********************************************************************************
* Result 2 and Result 3
********************************************************************************
********************************************************************************


{/***** Figures 8 and 9: Histogram of Output Changes from First to Second Round, and Second to Third Round */
********************************************************************************

histogram diff_2_1, discrete by(ct order_abc, ixaxes note("") graphregion(color(white))) xline(-16 -33, lpattern(dash)) color(navy) xtitle("Output Change from First to Second Round") xlabel (-50 0 50) ylabel(10 20 30 ,nogrid) percent
graph export "${out_path}histogram_diff_2_1_2x2_two_vertical_lines.pdf", replace 

histogram diff_3_2, discrete by(ct order_abc , ixaxes note("") graphregion(color(white))) xline(-17 +17, lpattern(dash)) color(navy) xtitle("Output Change from Second to Third Round") xlabel (-50 0 50) ylabel(10 20 30 ,nogrid) percent
graph export "${out_path}histogram_diff_3_2_2x2_two_vertical_lines.pdf", replace 

}


********************************************************************************
{/***** Table 2: Change in output level from previous round */
********************************************************************************

preserve

expand 2, generate(stage)
gen diff_prime = cond(stage==0, diff_2_1, diff_3_2_prime)
gen no_reaction_prime = cond(stage==0, no_reaction_2_1, no_reaction_3_2)


eststo clear
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct order_abc $control_vars

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct order_abc $control_vars


esttab using "${out_path}table_change_effort.tex", replace keep( ct order_abc age female iq _cons) order( ct order_abc age female iq _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(1.ct "1 if CT" ct "1 if CT" female "1 if Female" age "Age" order_abc "1 if Choice Order A-B-C" iq "IQ Measure" _cons "Constant") ///
extracols( 4 ) varwidth(35) mlabels(none) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{center} \begin{tabular}{lccccccc} \hline \\ \multicolumn{6}{l}{Dependent variable: } \\ & \multicolumn{3}{l}{Change in output level from previous round} & \hspace*{0.9cm}& \multicolumn{3}{l}{1 if subject chose same output as in previous round} \\ \\") ///
 postfoot(" \hline \end{tabular} \end{center} \begin{flushleft} Notes: Quantile (median) regression (columns 1--3) and OLS estimates (columns 4--6). The dependent variable in columns 1--3 is the change in output level from the previous round; the output changes in the second decision of the choice order A-C-B are multiplied by -1 to make them comparable; coming from a payoff-maximizing output level, an output decrease is always optimal. The dependent variable in columns 4--6 is a dummy equaling 1 if the subject chose the same output as in the previous round. Each subject enters the regression twice, standard errors computed by block bootstrap clustered at the subject level are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{onehalfspace} ")

restore

}



********************************************************************************
{/***** Results underlying paragraph "To shed light on these status-quo effects, ..." on page 24: decision times for subjects who do not change output levels */
********************************************************************************

preserve
expand 2, generate(stage)
gen no_reaction_prime = cond(stage==0, no_reaction_2_1, no_reaction_3_2)

gen time_prime = cond(stage==0, time_2, time_3) 
local ouctome "time_prime"
local regressor "no_reaction_prime"

bootstrap, seed(1) cluster(id) reps($bs_reps): reg `outcome' `regressor' if ct==1, robust
bootstrap, seed(1) cluster(id) reps($bs_reps): reg `outcome' `regressor' order_abc age female iq if ct==1, robust

restore

}


{/***** Table 8: Change in output level from previous round (Sample restricted to observations with non-zero change in output level) */
********************************************************************************

preserve

expand 2, generate(stage)
gen diff_prime = cond(stage==0, diff_2_1, diff_3_2_prime)
gen no_reaction_prime = cond(stage==0, no_reaction_2_1, no_reaction_3_2)

eststo clear
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct if no_reaction_prime == 0
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct order_abc if no_reaction_prime == 0
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct order_abc $control_vars if no_reaction_prime == 0


esttab using "${out_path}table_change_effort_nonreact.tex", replace keep( ct order_abc age female iq _cons) order( ct order_abc age female iq _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(1.ct "1 if CT" ct "1 if CT" female "1 if Female" age "Age" order_abc "1 if Choice Order A-B-C" iq "IQ Measure" _cons "Constant") ///
 varwidth(35) mlabels(none) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{center} \begin{tabular}{lccc} \hline \\ \multicolumn{4}{l}{Dependent variable: } \\ & \multicolumn{3}{l}{Change in output level from previous round} \\ \\") ///
 postfoot(" \hline \end{tabular} \end{center} \begin{flushleft} Notes: Quantile (median) regressions. The sample is restricted to observations with a non-zero change in output level from the previous round. The dependent variable is the change in output level from the previous round; the output changes in the second decision of the choice order A-C-B are multiplied by -1 to make them comparable; coming from a payoff-maximizing output level, an output decrease is always optimal. Each subject enters the regression twice, standard errors computed by block bootstrap clustered at the subject level are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{onehalfspace} ")

restore

}


********************************************************************************
********************************************************************************
* Result 4
********************************************************************************
********************************************************************************

********************************************************************************
{/***** Table 3: Effect of the magnitude of incentive change */
********************************************************************************

eststo clear
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg no_reaction_2_1 order_acb if ct==1, robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg no_reaction_2_1 order_acb $control_vars if ct==1, robust


esttab using "${out_path}table_incentive_size.tex", replace keep( order_acb age female iq _cons) order(order_acb age female iq _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(ct "1 if CT" female "1 if Female" age "Age" order_acb "1 if Choice Order A-C-B" iq "IQ Measure" _cons "Constant") ///
 varwidth(35) mlabels(none ) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{center} \begin{tabular}{lcc} \hline \\ \multicolumn{3}{l}{Dependent variable: 1 if subject chose same output in first and second round} \\ \\ ") ///
 postfoot(" \hline \end{tabular} \end{center} \begin{flushleft} Notes: OLS estimates. The sample is restricted to the complex treatment. The dependent variable is a dummy equaling 1 if the subject chose the same output as in the previous round. Bootstrapped standard errors are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{onehalfspace} ")

 
}



********************************************************************************
********************************************************************************
* Result 5
********************************************************************************
********************************************************************************


{/***** Figure 10: Decision Times in the Three Rounds (in Seconds) */
********************************************************************************

**** Time to reach decision (reminder shown 30s before this)
* max_time_instructions_a = 600;
* max_time_instructions_b = 240;
* max_time_instructions_c = 240;

local stages "1 2 3"
foreach x of local stages {
 capture drop cum_time_`x'_ct
 capture drop cum_time_`x'_st
 cumul time_`x' if ct, gen(cum_time_`x'_ct)
 cumul time_`x' if st, gen(cum_time_`x'_st)
 label var cum_time_`x'_ct "Complex"
 label var cum_time_`x'_st "Simple"
}


line cum_time_1_ct cum_time_1_st time_1, sort xline(570, lstyle(foreground) lpattern(dash)) xline(600, lstyle(foreground)) ylabel(,nogrid) graphregion(color(white)) saving(1, replace) legend(position(4) ring(0)) lpattern(dash solid) xtitle("Decision Time First Round")
line cum_time_2_ct cum_time_2_st time_2, sort xline(210, lstyle(foreground) lpattern(dash)) xline(240, lstyle(foreground)) ylabel(,nogrid) graphregion(color(white)) saving(2, replace) legend(off) lpattern(dash solid) xtitle("Decision Time Second Round")
line cum_time_3_ct cum_time_3_st time_3, sort xline(210, lstyle(foreground) lpattern(dash)) xline(240, lstyle(foreground)) ylabel(,nogrid) graphregion(color(white)) saving(3, replace) legend(off) lpattern(dash solid) xtitle("Decision Time Third Round")
graph combine 2.gph 3.gph, saving(23, replace) iscale(1) graphregion(color(white))
graph combine 1.gph 23.gph, rows(2) graphregion(color(white))
graph export "${out_path}cdf_time_combined.pdf", replace 
rm 1.gph
rm 2.gph
rm 3.gph
rm 23.gph

local stages "1 2 3"
foreach x of local stages {
 capture drop cum_time_`x'_ct
 capture drop cum_time_`x'_st
}

}

********************************************************************************
{/***** Table 4: Decision Time */
********************************************************************************

eststo clear
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_1 ct, robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_1 ct order_abc , robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_1 ct order_abc $control_vars, robust

eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_2 ct, robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_2 ct order_abc , robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_2 ct order_abc $control_vars, robust

eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_3 ct, robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_3 ct order_abc , robust
eststo: bootstrap, seed(1) strata(ct) reps($bs_reps): reg time_3 ct order_abc $control_vars, robust

esttab using "${out_path}table_decision_times.tex", replace keep( ct order_abc age female iq _cons) order(ct order_abc age female iq _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(1)) se(par fmt(1))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(ct "1 if CT" female "1 if Female" age "Age" order_abc "1 if Choice Order A-B-C" iq "IQ Measure" _cons "Constant") ///
 extracols( 4 7 ) varwidth(35) mlabels(none ) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{small} \begin{center} \resizebox{23cm}{!} { \begin{tabular}{l*{11}{c}} \hline \\ \multicolumn{10}{l}{Dependent variable:} \\ & \multicolumn{3}{c}{Decision time first round} && \multicolumn{3}{c}{Decision time second round} && \multicolumn{3}{c}{Decision time third round} \\ \\ ") ///
 postfoot(" \hline \end{tabular} } \end{center} \begin{flushleft} Notes: OLS estimates. The dependent variable is the time subjects took to decide in the three rounds of the experiment (measured in seconds). Standard errors computed by block bootstrap are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively.\end{flushleft} \end{small} \end{onehalfspace}")
 

 
 
} 


********************************************************************************
{/***** Welfare calculation base on decision time */
********************************************************************************

sum time_1 if ct, d
local median_dec_time_ct = `r(p50)'
sum time_1 if st, d
local median_dec_time_st = `r(p50)'
 
di "Treatment difference in median decision time (round 1): " `median_dec_time_ct' - `median_dec_time_st'
di "Median subject in CT takes " `median_dec_time_ct'/`median_dec_time_st' " as long as the median subject in ST"

sum Profit, d

* Median time in the experiment: about 50 min
di "Implied monetary cost of additional thinking time in CT: " `r(p50)'*(`median_dec_time_ct' - `median_dec_time_st')/(50*60) 

sum Profit if ct, d
sum Profit if st, d

}


********************************************************************************
********************************************************************************
* Result 6
********************************************************************************
********************************************************************************

********************************************************************************
{/***** Table 9: Change in output level from previous round - Interaction of IQ and Treatment */
********************************************************************************
 
preserve

expand 2, generate(stage)
gen diff_prime = cond(stage==0, diff_2_1, diff_3_2_prime)
gen no_reaction_prime = cond(stage==0, no_reaction_2_1, no_reaction_3_2)
capture gen ct_iq = ct*iq

eststo clear

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct ct_iq iq
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct ct_iq iq order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): qreg diff_prime ct ct_iq order_abc $control_vars 

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct ct_iq iq
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct ct_iq iq order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg no_reaction_prime ct ct_iq order_abc $control_vars



esttab using "${out_path}table_change_effort_iq.tex", replace keep( ct ct_iq order_abc age female iq _cons) order( ct iq ct_iq order_abc age female _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(1.ct "1 if CT" ct "1 if CT" female "1 if Female" age "Age" order_abc "1 if Choice Order A-B-C" iq "IQ Measure" ct_iq "CT * IQ Measure" _cons "Constant") ///
 extracols( 4 ) varwidth(35) mlabels(none) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{center} \begin{tabular}{lccccccc} \hline \\ \multicolumn{6}{l}{Dependent variable: } \\ & \multicolumn{3}{l}{Change in output level from previous round} & \hspace*{0.9cm}& \multicolumn{3}{l}{1 if subject chose same output as in previous round} \\ \\") ///
 postfoot(" \hline \end{tabular} \end{center} \begin{flushleft} Notes: Quantile (median) regression (columns 1--3) and OLS estimates (columns 4--6). The dependent variable in columns 1--3 is the change in output level from the previous round; the output changes in the second decision of the choice order A-C-B are multiplied by -1 to make them comparable; coming from a payoff-maximizing output level, an output decrease is always optimal. The dependent variable in columns 4--6 is a dummy equaling 1 if the subject chose the same output as in the previous round. Each subject enters the regression twice, standard errors computed by block bootstrap clustered at the subject level are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{onehalfspace} ")

restore



ranksum fraction_max if ct==0, by(high_iq)
ranksum fraction_max if ct==1, by(high_iq)



}





********************************************************************************
{/***** Table 10: First Round Earnings - Interaction of IQ and Treatment */
********************************************************************************


eststo clear

eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_1 ct ct_iq iq
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_1 ct ct_iq iq order_abc 
eststo: bootstrap, seed(1) cluster(id) strata(ct) reps($bs_reps): reg profit_1 ct ct_iq order_abc $control_vars 


esttab using "${out_path}iq_earnings_first_period.tex", replace keep( ct ct_iq order_abc age female iq _cons) order( ct iq ct_iq order_abc age female _cons ) style(tex) substitute(_ \_) ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs." "\(R^2\)")) ///
 varlabels(1.ct "1 if CT" ct "1 if CT" female "1 if Female" age "Age" order_abc "1 if Choice Order A-B-C" iq "IQ Measure" ct_iq "CT * IQ Measure" _cons "Constant") ///
 varwidth(35) mlabels(none) collabels(none) eqlabels(none) ///
 prehead("\begin{onehalfspace} \begin{center} \begin{tabular}{lccc} \hline \\ \multicolumn{3}{l}{Dependent variable: } \\ & \multicolumn{3}{l}{Earnings in the First Round} \\ \\") ///
 postfoot(" \hline \end{tabular} \end{center} \begin{flushleft} Notes: Quantile (median) regressions. The dependent variable are earnings in the first round measured in points (7 points were exchanged into one British pence). Standard errors computed by block bootstrap are in parentheses. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{onehalfspace} ")

}




********************************************************************************
{/***** Table 5: Within-Subject Correlation of Behavior in the Complex Treatment */
********************************************************************************

preserve
expand 2, generate(stage)
gen no_reaction_prime = cond(stage==0, no_reaction_2_1, no_reaction_3_2)

local outcome "no_reaction_prime"
gen sd_1_100 = sd_1/100
local regressor "sd_1_100"

eststo clear
quietly eststo `outcome': bootstrap, seed(1) cluster(id) reps($bs_reps): reg `outcome' `regressor' if ct==1, robust
quietly eststo `outcome'_control: bootstrap, seed(1) cluster(id) reps($bs_reps): reg `outcome' `regressor' order_abc age female iq if ct==1, robust

restore

local outcome "no_reaction_3_2"
local regressor "no_reaction_2_1"

quietly eststo `outcome': bootstrap, seed(1) reps($bs_reps): reg `outcome' `regressor' if ct==1, robust
quietly eststo `outcome'_control: bootstrap, seed(1) reps($bs_reps): reg `outcome' `regressor' order_abc age female iq if ct==1, robust


esttab using "${out_path}table_within_correlation.tex", replace style(tex) substitute(_ \_) label ///
 cells(b(star fmt(2)) se(par fmt(2))) starlevels(* 0.1 ** 0.05 *** 0.01) ///
 stats(N , fmt(0 3 2) labels("N.Obs.")) ///
 varlabels(sd_1_100 "Distance to payoff-maximizing choice (Round 1) / 100" no_reaction_2_1 "1 if subject chose same output in rounds 1 and 2" _cons "Constant") ///
 varwidth(55) mlabels(none ) collabels(none) eqlabels(none) nomtitles ///
 indicate("Control Variables = *order_abc age iq female*") ///
 prehead("\begin{onehalfspace} \begin{footnotesize} \begin{center} \resizebox{23cm}{!} { \begin{tabular}{l*{4}{c}} \hline \\ \multicolumn{4}{l}{Dependent variable:} \\ & \multicolumn{2}{c}{1 if subject chose same output as in previous round} & \multicolumn{2}{c}{1 if subject chose same output in rounds 2 and 3} \\ \\ ") ///
 postfoot(" \hline \end{tabular} } \end{center} \begin{flushleft} Notes: OLS estimates. The sample is confined to individuals in the complex treatment. Control variables are choice order, age, gender, and IQ. Each subject enters the regression twice for columns 1 and 2; standard errors computed by block bootstrap are in parentheses and are clustered by subject in columns 1 and 2. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{footnotesize} \end{onehalfspace}")

}
 






********************************************************************************
********************************************************************************
* Discussion Section
********************************************************************************
********************************************************************************


********************************************************************************
{/**** Estimation of bounds on k */
********************************************************************************


preserve
	drop if ct

**** sliders in C in ABC
	count if order_abc==1
	local n_st = r(N)
	count if (sliders_c > 21 & sliders_c < 29) & order_abc==1
	local c_in_21_29 = r(N)
	count if (sliders_c == 21 | sliders_c == 29) & order_abc==1
	local c_in_21_29 = (`c_in_21_29' + r(N)/2 )/`n_st'
	
	di "Share of subjects in ST schedule C in ABC with sliders in [21,29] (indicating k>=4): " `c_in_21_29'
	
****	sliders in B in ACB

	count if order_abc==0
	local n_st = r(N)
	count if (sliders_b > 38 & sliders_b < 46) & order_abc==0
	local b_in_38_46 = r(N)
	count if ( sliders_b == 38 | sliders_b == 46 ) & order_abc==0
	local b_in_38_46 = (`b_in_38_46' + r(N)/2 )/`n_st'
	
	di "Share of subjects in ST schedule B in ACB with sliders in [38,46] (indicating k>=4): " `b_in_38_46'

restore
	
	
}



********************************************************************************
********************************************************************************
* Appendix A
********************************************************************************
********************************************************************************

********************************************************************************
{/***** Robustness Check : Free effort phase */
******************************************************************************** 

tab sliders_pt2
tab time_sliders_pt2

bootstrap, seed(1) cluster(id) reps($bs_reps): tobit sliders_pt2 ct, ll(0) ul(144) 

* "After having decided on the number of sliders, actually positioning the sliders was very stressful." 1="Disagree completely"; 6="Agree completely ";
bootstrap, seed(1) cluster(id) reps($bs_reps): tobit stressful_task ct, ll(0) ul(6)



}









********************************************************************************
********************************************************************************
********************************************************************************

log close



